@@ -7,7 +7,7 @@ except ImportError:
     from typing import Union, Optional, List, Dict
     from typing_extensions import Literal
 
-def CMD(command:str, wait:bool=True, shell:bool=True, sudo:bool=False):
+def CMD(command:str, wait:bool=True, shell:bool=True, sudo:bool=False, **args):
     """Call system cmd console to execute a command (`subprocess.Popen`).
 
     Args:
@@ -15,11 +15,12 @@ def CMD(command:str, wait:bool=True, shell:bool=True, sudo:bool=False):
         wait (bool): If True, wait until the command finishes and return the handle, otherwise directly return the handle.
         shell (bool): If True, display shell for `subprocess.Popen`, otherwise ignored.
         sudo (bool): If True, pre-attach "sudo" in front of the command, otherwise ignored.
+        args: Custom args for `Popen` to be appended.
     Returns:
-        bool: Return the handle created by `subprocess.Popen`.
+        Return the handle created by `subprocess.Popen`.
     """
     sudo_command = ("sudo " if sudo else "")+str(command)
-    h = Popen(sudo_command,shell=shell)
+    h = Popen(sudo_command,shell=shell,**args)
     if wait:
         h.wait()
     return h
@@ -57,6 +58,21 @@ def PIP(package:str, source:str="", pip3:bool=True, upgrade:bool=False, force:bo
     pip_command = "pip3" if pip3 else "pip"
     CMD(f"{pip_command} install {package} {source_command}{upgrade_command}{reinstall_command}{nodeps_command}{args}",wait=True)
 
+def RSYNC(src:str, dst:str, wait:bool=True, args:str="-r -vP"):
+    """Call system cmd console to execute `rsync` command (`subprocess.Popen`).
+
+    Args:
+        src (str): The source path of `rsync`.
+        dst (str): The destination path of `rsync`.
+        wait (bool): If True, wait until the command finishes and return the handle, otherwise directly return the handle.
+        args: Custom args for `Popen` to be appended.
+    Returns:
+        Return the handle created by `subprocess.Popen`.
+    """
+    return CMD(
+        f"rsync {args} {src} {dst}", wait=wait
+    )
+
 def __import_unsafe__(name:str, alias:str, module_globals:Dict, force_reimport:bool=False):
     if force_reimport or (alias not in module_globals):
         if (alias is None) and ("." in name):
